JsonBufferKey

Struct JsonBufferKey 

pub struct JsonBufferKey { /* private fields */ }
Similar to a BufferKey except it can be used for any buffer that supports serialization and deserialization without knowing the buffer’s specific message type at compile time.

This can key be used with a World to directly view or manipulate the contents of a buffer through the JsonBufferWorldAccess interface.

Implementations

Source

impl JsonBufferKey

pub fn downcast_for_message<T: 'static>(self) -> Option<BufferKey<T>>

Downcast this into a concrete BufferKey for the specified message type.

To downcast to a specialized kind of key, use Self::downcast_buffer_key instead.

pub fn downcast_buffer_key<KeyType: 'static>(self) -> Option<KeyType>

pub fn as_any_buffer_key(self) -> AnyBufferKey

Cast this into an AnyBufferKey