JsonMessageViewResult

Type Alias JsonMessageViewResult 

pub type JsonMessageViewResult = Result<Option<JsonMessage>, Error>;
The return type for functions that give a JSON view of a message in a buffer. If an error occurs while attempting to serialize the message, this will return Err.

If this returns Ok then None means there was no message available at the requested location while Some will contain a serialized copy of the message.

Aliased Type

pub enum JsonMessageViewResult {
    Ok(Option<Value>),
    Err(Error),
}

Variants

1.0.0

Ok(Option<Value>)

Contains the success value

1.0.0

Err(Error)

Contains the error value