Module split

Module split 

Structs

SplitAsList
This is a newtype that implements Splittable for anything that can be turned into an iterator, but always splits it as if the iterator is list-like.
SplitAsMap
This is a newtype that implements Splittable for anything that can be turned into an iterator whose items take the form of a (key, value) pair where key meets all the bounds needed for a Splittable key.
SplitBuilder
This is returned by Chain::split and allows you to connect to the split pieces.
SplitDispatcher
Used by implementers of the Splittable trait to help them send their split values to the proper input slots.
SplitOutputs
This tracks the connections that have been made to a split. This can be retrieved from SplitBuilder by calling SplitBuilder::outputs. You can then continue building connections by calling SplitOutputs::build.

Enums

ListSplitKey
This enum allows users to key into splittable list-like structures based on the sequence in which an item appears in the list. It also has an option for keying into any items that were left over in the sequence.
MapSplitKey
This enum allows users to key into splittable map-like structures based on the presence of a specific value or based on the sequence in which a value is reached that wasn’t associated with a specific key.
SplitConnectionError
Information about why a connection to a split failed

Traits

ForRemaining
Get the key that represents all remaining/unspecified keys. Implemented by ListSplitKey and MapSplitKey.
FromSequential
Turn a sequence index into a split key. Implemented by ListSplitKey and MapSplitKey.
FromSpecific
Turn a specific key into a split key. Implemented by MapSplitKey.
IgnoreSplitChainResult
A helper trait that allows users to ignore any failures while chaining connections to a split.
Splittable
Implementing this trait on a struct will allow the Chain::split operation to be performed on outputs of that type.

Type Aliases

SplitBranchResult
This is a type alias for the result returned by the branching SplitBuilder functions. If the last connection succeeded, you will receive Ok with the SplitBuilder which you can keep building off of. Otherwise if the last connection failed, you will receive an Err with the SplitBuilder bundled with SplitConnectionError to tell you what went wrong. You can continue building with the SplitBuilder even if an error occurred.
SplitChainResult
This is a type alias for the chain-building methods in SplitBuilder. It will either return the output of the chain building function or an error.