pub struct SplitOutputs<T: Splittable> { /* private fields */ }Expand description
This tracks the connections that have been made to a split. This can be
retrieved from SplitBuilder by calling SplitBuilder::outputs.
You can then continue building connections by calling SplitOutputs::build.
Implementations
Sourceimpl<T: Splittable> SplitOutputs<T>
impl<T: Splittable> SplitOutputs<T>
Sourcepub fn build<'w, 's, 'a, 'b>(
self,
builder: &'b mut Builder<'w, 's, 'a>,
) -> SplitBuilder<'w, 's, 'a, 'b, T> ⓘ
pub fn build<'w, 's, 'a, 'b>( self, builder: &'b mut Builder<'w, 's, 'a>, ) -> SplitBuilder<'w, 's, 'a, 'b, T> ⓘ
Resume building connections for this split.