pub struct SectionTemplate {
pub inputs: InputRemapping,
pub outputs: Vec<OperationName>,
pub buffers: InputRemapping,
pub ops: Operations,
}Fields
inputs: InputRemappingThese are the inputs that the section is exposing for its sibling operations to send outputs into.
outputs: Vec<OperationName>These are the outputs that the section is exposing so you can connect them into siblings of the section.
buffers: InputRemappingThese are the buffers that the section is exposing for you to read, write, join, or listen to.
ops: OperationsOperations that define the behavior of the section.