Module node

Module node 

Modules

dyn_node

Structs

ForkCloneOutput
The output of a cloning fork node. Use Self::clone_output to create a cloned output that you can connect to an input slot.
ForkOptionOutput
The output of a fork option operation. Each output can be connected to one input slot.
ForkResultOutput
The output of a fork result operation. Each output can be connected to one input slot.
InputSlot
The slot that receives input for a node. When building a workflow, you can connect the output of a node to this, as long as the types match.
Node
A collection of all the inputs and outputs for a node within a workflow.
Output
The output of a node. This can only be connected to one input slot. If the Response parameter can be cloned then you can call Self::fork_clone to transform this into a ForkCloneOutput and then connect the output into any number of input slots.