Output

Struct Output 

pub struct Output<Response> { /* private fields */ }
The output of a node. This can only be connected to one input slot. If the Response parameter can be cloned then you can call Self::fork_clone to transform this into a ForkCloneOutput and then connect the output into any number of input slots.

Output intentionally does not implement copy or clone because it must only be consumed exactly once.

Implementations

Source

impl<Response: 'static + Send + Sync> Output<Response>

pub fn chain<'w, 's, 'a, 'b>( self, builder: &'b mut Builder<'w, 's, 'a>, ) -> Chain<'w, 's, 'a, 'b, Response>
where Response: 'static + Send + Sync,

Create a chain that builds off of this response.

pub fn fork_clone( self, builder: &mut Builder<'_, '_, '_>, ) -> ForkCloneOutput<Response>
where Response: Clone,

Create a node that will fork the output along multiple branches, giving a clone of the output to each branch.

pub fn id(&self) -> Entity

Get the entity that this output will be sent to.

pub fn scope(&self) -> Entity

Get the scope that this output exists inside of.