Module service

Module service 

Re-exports

pub use discovery::*;
pub use traits::*;

Modules

discovery
service_utils
traits

Structs

AsAsyncService
Take any system that was not decalred as a service and transform it into a blocking service that can be passed into a ServiceBuilder.
AsBlockingService
Take any system that was not declared as a service and transform it into a blocking service that can be passed into a ServiceBuilder.
Blocking
ContinuousQuery
ContinuousQueueMut
ContinuousQueueView
ContinuousServiceKey
DeliveryInstructions
When using a service, you can bundle in delivery instructions that affect how multiple requests to the same service may interact with each other.
DeliveryLabelId
Newtype to store types that implement DeliveryLabel
IntoContinuousServiceBuilderMarker
MissingStreamsError
OrderMut
OrderView
Service
Service is the public API handle for referring to an existing service provider. You can obtain a service using:
ServiceBuilder
ServiceInstructions
This is a more advanced alternative to Service which allows you to specify additional DeliveryInstructions. This is kept as a separate data structure because it cannot be copied (only cloned).

Enums

ScheduleConfigs
Single or nested configurations for Schedulables.

Traits

AddContinuousServicesExt
AddServicesExt
This trait extends the App interface so that services can be added while configuring an App.
AsDeliveryInstructions
Allow anything that can be converted into DeliveryInstructions to have access to the Self::preempt and Self::ensure methods.
DeliveryLabel
IntoAsyncService
IntoBlockingService
This trait allows any system to be converted into a blocking service.
IsAsyncService
SpawnServicesExt
This trait extends the Commands interface so that services can spawned from any system.

Functions

event_streaming_service
Implementation for crate::AddContinuousServicesExt::spawn_event_streaming_service

Derive Macros

DeliveryLabel