AnonymousStream

Struct AnonymousStream 

pub struct AnonymousStream<S: StreamEffect>(/* private fields */);
A wrapper to turn any StreamEffect into an anonymous (unnamed) stream. This should be used if you want a stream with the same behavior as StreamOf but with some additional side effect. The input and output data types of the stream may be different.