In

Struct In 

pub struct In<T>(pub T);
A SystemInput type which denotes that a System receives an input value of type T from its caller.

Systems may take an optional input which they require to be passed to them when they are being run. For FunctionSystems the input may be marked with this In type, but only the first param of a function may be tagged as an input. This also means a system can only have one or zero input parameters.

See SystemInput to learn more about system inputs in general.

Examples

Here is a simple example of a system that takes a usize and returns the square of it.

fn square(In(input): In<usize>) -> usize {
    input * input
}

let mut world = World::new();
let mut square_system = IntoSystem::into_system(square);
square_system.initialize(&mut world);

assert_eq!(square_system.run(12, &mut world), 144);

Tuple Fields

0: T