Sendish

Trait Sendish 

pub trait Sendish: Send { }
This trait is used as a trait bound that is equivalent to Send except when the single_threaded_async feature is active, in which case it is no longer a bound at all because the single threaded async executor does not require tasks to be Send.

Implementors

Source

impl<T: Send> Sendish for T

Available on non-crate feature single_threaded_async only.