pub struct AnyBufferKey { /* private fields */ }Expand description
Similar to a BufferKey except it can be used for any buffer without
knowing the buffer’s message type at compile time.
This can key be used with a World to directly view or manipulate the
contents of a buffer through the AnyBufferWorldAccess interface.
Implementations
Sourceimpl AnyBufferKey
impl AnyBufferKey
Sourcepub fn downcast_for_message<Message: 'static>(
self,
) -> Option<BufferKey<Message>>
pub fn downcast_for_message<Message: 'static>( self, ) -> Option<BufferKey<Message>>
Downcast this into a concrete BufferKey for the specified message type.
To downcast to a specialized kind of key, use Self::downcast_buffer_key instead.
Sourcepub fn downcast_buffer_key<KeyType: 'static>(self) -> Option<KeyType>
pub fn downcast_buffer_key<KeyType: 'static>(self) -> Option<KeyType>
Downcast this into a different special buffer key representation, such
as a JsonBufferKey.