pub type JsonMessageReplaceResult = Result<JsonMessage, Error>;Expand description
The return type for functions that replace (swap out) one message with
another. If an error occurs while serializing or deserializing either
message to/from the buffer’s message type then this will return Err.
If this returns Ok then the message was successfully replaced, and the
value inside Ok is the message that was previously in the buffer.
Aliased Type
pub enum JsonMessageReplaceResult {
Ok(Value),
Err(Error),
}