pub type JsonMessageViewResult = Result<Option<JsonMessage>, Error>;Expand description
The return type for functions that give a JSON view of a message in a buffer.
If an error occurs while attempting to serialize the message, this will return
Err.
If this returns Ok then None means there was no message available at
the requested location while Some will contain a serialized copy of the
message.
Aliased Type
pub enum JsonMessageViewResult {
Ok(Option<Value>),
Err(Error),
}