pub struct DynStreamOutputPack {
pub named: HashMap<Cow<'static, str>, DynOutput>,
pub anonymous: HashMap<TypeInfo, DynOutput>,
}Expand description
This is a pack of streams outputs whose message types are determined at runtime.
This can be created using the crate::StreamPack.
Fields
named: HashMap<Cow<'static, str>, DynOutput>anonymous: HashMap<TypeInfo, DynOutput>Implementations
Sourceimpl DynStreamOutputPack
impl DynStreamOutputPack
Sourcepub fn add_named(
&mut self,
name: impl Into<Cow<'static, str>>,
output: impl Into<DynOutput>,
)
pub fn add_named( &mut self, name: impl Into<Cow<'static, str>>, output: impl Into<DynOutput>, )
Add a named stream output to this pack.
Sourcepub fn take_named(&mut self, name: &str) -> Option<DynOutput>
pub fn take_named(&mut self, name: &str) -> Option<DynOutput>
Take a named stream output from this pack. The output needs to be taken because it will get consumed when it is connected to an input slot.
Sourcepub fn add_anonymous(&mut self, output: impl Into<DynOutput>)
pub fn add_anonymous(&mut self, output: impl Into<DynOutput>)
Add an anonymous stream output to this pack.
Sourcepub fn take_anonymous(&mut self, type_info: &TypeInfo) -> Option<DynOutput>
pub fn take_anonymous(&mut self, type_info: &TypeInfo) -> Option<DynOutput>
Take an anonymous stream output from this pack. The output needs to be taken because it will get consumed when it is connected to an input slot.
Sourcepub fn available_names(&self) -> HashMapKeys<'_, Cow<'static, str>, DynOutput>
pub fn available_names(&self) -> HashMapKeys<'_, Cow<'static, str>, DynOutput>
Get the names that are available in this stream pack. This may provide
a different result after you have called Self::take_named.