pub struct Output<Response> { /* private fields */ }Expand description
The output of a node. This can only be connected to one input slot. If the
Response parameter can be cloned then you can call Self::fork_clone to
transform this into a ForkCloneOutput and then connect the output into
any number of input slots.
Output intentionally does not implement copy or clone because it must only
be consumed exactly once.
Implementations
Sourceimpl<Response: 'static + Send + Sync> Output<Response>
impl<Response: 'static + Send + Sync> Output<Response>
Sourcepub fn chain<'w, 's, 'a, 'b>(
self,
builder: &'b mut Builder<'w, 's, 'a>,
) -> Chain<'w, 's, 'a, 'b, Response>
pub fn chain<'w, 's, 'a, 'b>( self, builder: &'b mut Builder<'w, 's, 'a>, ) -> Chain<'w, 's, 'a, 'b, Response>
Create a chain that builds off of this response.
Sourcepub fn fork_clone(
self,
builder: &mut Builder<'_, '_, '_>,
) -> ForkCloneOutput<Response>where
Response: Clone,
pub fn fork_clone(
self,
builder: &mut Builder<'_, '_, '_>,
) -> ForkCloneOutput<Response>where
Response: Clone,
Create a node that will fork the output along multiple branches, giving a clone of the output to each branch.