Re-exports
Modules
Structs
- AsAsync
Service - Take any system that was not decalred as a service and transform it into a blocking service that can be passed into a ServiceBuilder.
- AsBlocking
Service - Take any system that was not declared as a service and transform it into a blocking service that can be passed into a ServiceBuilder.
- Blocking
- Continuous
Query - Continuous
Queue Mut - Continuous
Queue View - Continuous
Service Key - Delivery
Instructions - When using a service, you can bundle in delivery instructions that affect how multiple requests to the same service may interact with each other.
- Delivery
Label Id - Newtype to store types that implement
DeliveryLabel - Into
Continuous Service Builder Marker - Missing
Streams Error - Order
Mut - Order
View - Service
Serviceis the public API handle for referring to an existing service provider. You can obtain a service using:- Service
Builder - Service
Instructions - This is a more advanced alternative to
Servicewhich allows you to specify additionalDeliveryInstructions. This is kept as a separate data structure because it cannot be copied (only cloned).
Enums
- Schedule
Configs - Single or nested configurations for
Schedulables.
Traits
- AddContinuous
Services Ext - AddServices
Ext - This trait extends the App interface so that services can be added while configuring an App.
- AsDelivery
Instructions - Allow anything that can be converted into
DeliveryInstructionsto have access to theSelf::preemptandSelf::ensuremethods. - Delivery
Label - Into
Async Service - Into
Blocking Service - This trait allows any system to be converted into a blocking service.
- IsAsync
Service - Spawn
Services Ext - This trait extends the Commands interface so that services can spawned from any system.
Functions
- event_
streaming_ service - Implementation for
crate::AddContinuousServicesExt::spawn_event_streaming_service