Module workflow
crossflow
0.0.6
Module workflow
Module Items
Structs
Enums
Traits
In crate crossflow
crossflow
Module
workflow
Structs

Scope
The internal interface of the scope, used to connect elements inside the scope to the start, terminate, and stream operations of the scope.
Scope
Settings
Settings which determine how the top-level scope of the workflow behaves.
Workflow
Settings
Settings that describe some aspects of a workflow’s behavior.
Enums

Delivery
Settings
Settings which determine how the workflow delivers its requests: in serial (handling one request at a time) or in parallel (allowing multiple requests at a time).
Traits

Spawn
Workflow
Ext
Trait to allow workflows to be spawned from a
Commands
or a
World
.